@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
 
-from django.http import HttpResponseRedirect, HttpResponse
+from django.http import HttpResponseRedirect
 from django.template import RequestContext
 from django.shortcuts import render_to_response
 from django.contrib import admin, messages
 from django.db.models import Q
 from django.utils.http import urlencode, urlunquote
 
-from django_stachoutils import inline_update
 from django_stachoutils.options import paginate
 from django_stachoutils.views.actions import regroup_actions
 
 ORDER_BY_ATTR = 'o'
 ORDER_TYPE_ATTR = 'ot'
 
+
 def generic_change_response(request, url_continue, url_add_another, url_default):
     if "_continue" in request.POST:
         return HttpResponseRedirect(url_continue)
@@ -22,7 +22,8 @@ def generic_change_response(request, url_continue, url_add_another, url_default)
     else:
         return HttpResponseRedirect(url_default)
 
-def liste_generique(request, queryset, columns, template, Model, ClassAdmin=None, 
+
+def liste_generique(request, queryset, columns, template, Model, ClassAdmin=None,
                     actions=[], filters=(), links=(), search=(), default_order=None,
                     paginate_by_default=100, paginates_by=[], qset_modifier=None,
                     qset_modifier_args=[], extra_params={}):
@@ -40,11 +41,11 @@ def liste_generique(request, queryset, columns, template, Model, ClassAdmin=None
     actions_par_groupe = []
     if ClassAdmin and actions:
         adm = ClassAdmin(Model, admin.site)
-        admin_actions = adm.get_actions(request) # {'invalider': (<unbound method ProgrammeAdmin.invalider>, 'invalider', u'Invalider en...'), ...}
+        admin_actions = adm.get_actions(request)  # {'invalider': (<unbound method ProgrammeAdmin.invalider>, 'invalider', u'Invalider en...'), ...}
         for group, actions_in_group in actions:
-            actions_dispos = [(callable(action) and action.func_name or action,\
-                               admin_actions.has_key(action) and admin_actions[action][2] or action.short_description)
-                              for action in actions_in_group if admin_actions.has_key(action) or callable(action)]
+            actions_dispos = [(callable(action) and action.func_name or action,
+                              action in admin_actions and admin_actions[action][2] or action.short_description)
+                              for action in actions_in_group if action in admin_actions or callable(action)]
             if actions_dispos:
                 actions_par_groupe.append((group, actions_dispos))
 
@@ -64,7 +65,7 @@ def liste_generique(request, queryset, columns, template, Model, ClassAdmin=None
         return render_to_response(template, c, context_instance=RequestContext(request))
 
     # Filter columns according to the user permissions.
-    columns = [c for c in columns if has_column_perm(request.user, c)]
+    columns = [col for col in columns if has_column_perm(request.user, col)]
 
     # Search.
     if request.GET.get('q'):
@@ -92,18 +93,16 @@ def liste_generique(request, queryset, columns, template, Model, ClassAdmin=None
     queryset = queryset.filter(**filters_for_queryset(current_filters)).distinct()
     if qset_modifier:
         queryset = qset_modifier(queryset, *qset_modifier_args)
-    
+
     count_across = queryset.count()
     page = paginate(request, queryset, paginate_by_default)
 
     # Filters.
-    closed_filters = user_settings.get('%s_closed_filters'%list_id, [])
+    closed_filters = user_settings.get('%s_closed_filters' % list_id, [])
     filters = [get_filter(Model, current_filters, closed_filters, f) for f in filters]
 
     # Exec action.
     if request.method == 'POST':
-        if request.is_ajax():
-            return HttpResponse(inline_update(Model, request.POST['id'], request.POST['attr'], request.POST['value']))
         action = request.POST.get('action')
         selected = request.POST.getlist('_selected_action')
         if not action:
@@ -127,7 +126,7 @@ def liste_generique(request, queryset, columns, template, Model, ClassAdmin=None
                         return response
                     else:
                         return HttpResponseRedirect("")
-        
+
     c = {
         'object_list': page.object_list,
         'page': page,
@@ -135,7 +134,7 @@ def liste_generique(request, queryset, columns, template, Model, ClassAdmin=None
         'paginates_by': request.GET.get('paginates_by', paginates_by),
         'columns': columns,
         'actions': actions_par_groupe,
-        'filtres': filters, # renommer en filters.
+        'filtres': filters,  # renommer en filters.
         'links': links,
         'search': [s[0] for s in search],
         'get_params': dict(request.GET.items()),
@@ -169,12 +168,12 @@ def get_filter(model, current_filters, closed_filters, filtr):
         'attr':  filtr,
         'filter_test':  'exact',
     }
- 
+
     if filtr.__class__.__name__ == 'tuple':
         p['attr'] = filtr[0]
         p.update(filtr[1])
 
-    choices, empty_choice, attr, filter_test = p['choices'], p['empty_choice'], p['attr'], p['filter_test'] 
+    choices, empty_choice, attr, filter_test = p['choices'], p['empty_choice'], p['attr'], p['filter_test']
 
     filter_string = attr
     attrs = attr.split('__')
@@ -185,7 +184,7 @@ def get_filter(model, current_filters, closed_filters, filtr):
         try:
             mod = mod._meta.get_field(rel_model).rel.to
         except:
-            mod = getattr(mod, '%s_set'%rel_model).related.model
+            mod = getattr(mod, '%s_set' % rel_model).related.model
 
     field = mod._meta.get_field(attr)
     name = field.verbose_name
@@ -202,7 +201,7 @@ def get_filter(model, current_filters, closed_filters, filtr):
 
     choices = [(lambda f=F(o, attr, filter_string, filter_test, current_filters): (f.url, f.label, f.is_selected))() for o in choices]
     choices.insert(0, (lambda f=FilterAll(attr, filter_string, filter_test, current_filters): (f.url, f.label, f.is_selected))())
-    if empty_choice: 
+    if empty_choice:
         choices.append((lambda f=FilterNone(model, attr, filter_string, current_filters): (f.url, f.label, f.is_selected))())
     return (name, (name in closed_filters), choices)
 
@@ -267,8 +266,8 @@ class Filter(object):
             self.label = instance.__unicode__()
             self.value = str(instance.pk)
         self.current_filters = current_filters
-        self.key = '%s__%s'%(filter_string, test)
-        self.isnull = '%s__isnull'%(filter_string,)
+        self.key = '%s__%s' % (filter_string, test)
+        self.isnull = '%s__isnull' % (filter_string,)
         self._url = None
         self._is_selected = None
 
@@ -278,7 +277,8 @@ class Filter(object):
             filters = self.get_base_filters()
             out = filters.copy()
             for k, v in filters.iteritems():
-                if not v: del out[k] # supp les filtres vides.
+                if not v:
+                    del out[k]  # supp les filtres vides.
             self._url = urlencode(out)
         return self._url
     url = property(_get_url)
@@ -288,14 +288,14 @@ class Filter(object):
         # on update le parametre si deja present dans l'url.
         filters.update({self.key: self.value})
         # on vire l'eventuel filtre is_null.
-        if filters.has_key(self.isnull): del filters[self.isnull]
+        if self.isnull in filters:
+            del filters[self.isnull]
         return filters
 
     def _get_is_selected(self):
         """L'url d'un filtre doit conserver les filtres en cours pour être additifs. """
         if self._is_selected is None:
             selected = self.current_filters.get(self.key, None)
-            empty_selected = self.current_filters.get(self.isnull, None)
             self._is_selected = (self.value == selected)
         return self._is_selected
     is_selected = property(_get_is_selected)
@@ -318,8 +318,7 @@ class FilterAll(Filter):
 
     def _get_is_selected(self):
         if self._is_selected is None:
-            if not self.current_filters.has_key(self.key) and not\
-                   self.current_filters.has_key(self.isnull):
+            if self.key not in self.current_filters and self.isnull not in self.current_filters:
                 self._is_selected = True
         return self._is_selected
     is_selected = property(_get_is_selected)
@@ -338,7 +337,7 @@ class FilterNone(Filter):
         self.value = True
 
     def _get_is_selected(self):
-        if self.current_filters.has_key(self.isnull):
+        if self.isnull in self.current_filters:
             self._is_selected = True
         return self._is_selected
     is_selected = property(_get_is_selected)
